@@ -15,6 +15,7 @@ test_that("plot for incidence object", {
 
   # constructing data
   i <- incidence(dat)
+  iog <- incidence(dat, groups = rep("this group", 200))
   i.3 <- incidence(dat, 3L)
   i.14 <- incidence(dat, 14L)
   i.sex <- incidence(dat, 7L, groups = sex)
@@ -28,6 +29,7 @@ test_that("plot for incidence object", {
   fit.i <- suppressWarnings(fit(i))
   fit.i.2 <- suppressWarnings(fit(i, split = 30))
   fit.i.3 <- suppressWarnings(fit(i.3[5:13]))
+  fit.POSIX <- suppressWarnings(fit(i.POSIX))
   fit.sex <- suppressWarnings(fit(i.sex))
   fit.sex.o <- suppressWarnings(fit_optim_split(i.sex.o))
   fit.o <- suppressWarnings(fit_optim_split(pool(i.sex.o)))
@@ -40,10 +42,11 @@ test_that("plot for incidence object", {
   p.i <- plot(i)
   p.i.cum <- plot(cumulate(i))
   p.i.square <- plot(i, show_cases = TRUE)
-  expect_message(plot(i.sex, show_cases = TRUE, stack = FALSE))
+  expect_message(plot(i.sex, show_cases = TRUE, stack = FALSE), "`show_cases` requires the argument `stack = TRUE`")
 
   p.i.14 <- plot(i.14)
   p.i.2 <- plot(i, color = "blue", alpha = .2)
+  expect_message(p.iog <- plot(iog, color = c("this group" = "blue", "that group" = "red")), "1 colors were not used: \"that group\" = \"red\"")
   p.i.3 <- plot(i.3, fit = fit.i.3, color = "red")
   p.sex <- plot(i.sex)
   p.sex.cum <- plot(cumulate(i.sex))
@@ -54,6 +57,7 @@ test_that("plot for incidence object", {
                   color = c(male = "salmon3", female = "gold2"))
   p.isoweek <- plot(i.isoweek)
   p.POSIX <- plot(i.POSIX)
+  p.POSIX.f <- plot(i.POSIX, fit = fit.POSIX)
   p.isoweek.2 <- plot(i.isoweek, labels_iso = FALSE)
   p.month <- plot(i.sexmonth)
   p.quarter <- plot(i.sexquarter)
@@ -67,11 +71,13 @@ test_that("plot for incidence object", {
   vdiffr::expect_doppelganger("incidence plot with specified color and alpha", p.i.2)
   vdiffr::expect_doppelganger("incidence plot with interval of 3 days, fit and specified color", p.i.3)
   vdiffr::expect_doppelganger("grouped incidence plot", p.sex)
+  vdiffr::expect_doppelganger("grouped incidence plot with one group", p.iog)
   vdiffr::expect_doppelganger("grouped incidence plot, cumulative", p.sex.cum)
   vdiffr::expect_doppelganger("grouped incidence plot with fit", p.sex.2)
   vdiffr::expect_doppelganger("grouped incidence plot with color palette", p.sex.3)
   vdiffr::expect_doppelganger("grouped incidence plot with specified color", p.sex.4)
   vdiffr::expect_doppelganger("incidence plot from POSIXct data", p.POSIX)
+  vdiffr::expect_doppelganger("incidence plot from POSIXct data with fit", p.POSIX.f)
   vdiffr::expect_doppelganger("incidence plot with isoweek labels", p.isoweek)
   vdiffr::expect_doppelganger("incidence plot without isoweek labels", p.isoweek.2)
   vdiffr::expect_doppelganger("incidence plot by month", p.month)
